////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  gtm_1_0_0.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "gtm_1_0_0.h"
#include "parametersetmanager.h"

GTM_1_0_0_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool gtm10_rgn_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "maxval_th") == 0)
    {
        ParameterUtils::DoubleToString((double)maxval_th, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "key_min_th") == 0)
    {
        ParameterUtils::DoubleToString((double)key_min_th, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "key_max_th") == 0)
    {
        ParameterUtils::DoubleToString((double)key_max_th, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "key_hist_bin_weight") == 0)
    {
        ParameterUtils::DoubleToString((double)key_hist_bin_weight, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "yout_maxval") == 0)
    {
        ParameterUtils::DoubleToString((double)yout_maxval, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minval_th") == 0)
    {
        ParameterUtils::DoubleToString((double)minval_th, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "a_middletone") == 0)
    {
        ParameterUtils::DoubleToString((double)a_middletone, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "middletone_w") == 0)
    {
        ParameterUtils::DoubleToString((double)middletone_w, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "temporal_w") == 0)
    {
        ParameterUtils::DoubleToString((double)temporal_w, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "max_percentile") == 0)
    {
        ParameterUtils::DoubleToString((double)max_percentile, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "min_percentile") == 0)
    {
        ParameterUtils::DoubleToString((double)min_percentile, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "reserved_1") == 0)
    {
        ParameterUtils::DoubleToString((double)reserved_1, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "reserved_2") == 0)
    {
        ParameterUtils::DoubleToString((double)reserved_2, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "extra_ratio_factor") == 0)
    {
        ParameterUtils::DoubleToString((double)extra_ratio_factor, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "dark_index_range") == 0)
    {
        ParameterUtils::DoubleToString((double)dark_index_range, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "yratio_base_manual_tab") == 0)
    {
        __result = yratio_base_manual_tab.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "manual_curve_strength") == 0)
    {
        ParameterUtils::DoubleToString((double)manual_curve_strength, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "midlight_threshold_low") == 0)
    {
        ParameterUtils::DoubleToString((double)midlight_threshold_low, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "midlight_threshold_high") == 0)
    {
        ParameterUtils::DoubleToString((double)midlight_threshold_high, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "lowlight_w") == 0)
    {
        ParameterUtils::DoubleToString((double)lowlight_w, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "highlight_w") == 0)
    {
        ParameterUtils::DoubleToString((double)highlight_w, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "max_ratio") == 0)
    {
        ParameterUtils::DoubleToString((double)max_ratio, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "luma_peak_th0") == 0)
    {
        ParameterUtils::DoubleToString((double)luma_peak_th0, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "luma_peak_th1") == 0)
    {
        ParameterUtils::DoubleToString((double)luma_peak_th1, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "stretch_gain_0") == 0)
    {
        ParameterUtils::DoubleToString((double)stretch_gain_0, __value, __size);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "stretch_gain_1") == 0)
    {
        ParameterUtils::DoubleToString((double)stretch_gain_1, __value, __size);
        __result = true;
    }

    return __result;
}

bool gtm10_rgn_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "maxval_th") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            maxval_th = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "key_min_th") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            key_min_th = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "key_max_th") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            key_max_th = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "key_hist_bin_weight") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            key_hist_bin_weight = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "yout_maxval") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            yout_maxval = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minval_th") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minval_th = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "a_middletone") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            a_middletone = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "middletone_w") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            middletone_w = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "temporal_w") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            temporal_w = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "max_percentile") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            max_percentile = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "min_percentile") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            min_percentile = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "reserved_1") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            reserved_1 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "reserved_2") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            reserved_2 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "extra_ratio_factor") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            extra_ratio_factor = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "dark_index_range") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            dark_index_range = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "yratio_base_manual_tab") == 0)
    {
        __result = yratio_base_manual_tab.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "manual_curve_strength") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            manual_curve_strength = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "midlight_threshold_low") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            midlight_threshold_low = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "midlight_threshold_high") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            midlight_threshold_high = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "lowlight_w") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            lowlight_w = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "highlight_w") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            highlight_w = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "max_ratio") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            max_ratio = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "luma_peak_th0") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            luma_peak_th0 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "luma_peak_th1") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            luma_peak_th1 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "stretch_gain_0") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            stretch_gain_0 = (float)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "stretch_gain_1") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            stretch_gain_1 = (float)dblValue; 
        }
    }

    return __result;
}

bool gtm10_rgn_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // maxval_th
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("maxval_th", ParameterParserDataType::UInt32, (double)maxval_th, 0));
    }
    else if (PARAMETER_STRCMP(__name, "maxval_th") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)maxval_th, 0));
    }

    // key_min_th
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("key_min_th", ParameterParserDataType::UInt32, (double)key_min_th, 0));
    }
    else if (PARAMETER_STRCMP(__name, "key_min_th") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)key_min_th, 0));
    }

    // key_max_th
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("key_max_th", ParameterParserDataType::UInt32, (double)key_max_th, 0));
    }
    else if (PARAMETER_STRCMP(__name, "key_max_th") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)key_max_th, 0));
    }

    // key_hist_bin_weight
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("key_hist_bin_weight", ParameterParserDataType::Float, (double)key_hist_bin_weight));
    }
    else if (PARAMETER_STRCMP(__name, "key_hist_bin_weight") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)key_hist_bin_weight));
    }

    // yout_maxval
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("yout_maxval", ParameterParserDataType::UInt32, (double)yout_maxval, 0));
    }
    else if (PARAMETER_STRCMP(__name, "yout_maxval") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)yout_maxval, 0));
    }

    // minval_th
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minval_th", ParameterParserDataType::UInt32, (double)minval_th, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minval_th") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)minval_th, 0));
    }

    // a_middletone
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("a_middletone", ParameterParserDataType::Float, (double)a_middletone));
    }
    else if (PARAMETER_STRCMP(__name, "a_middletone") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)a_middletone));
    }

    // middletone_w
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("middletone_w", ParameterParserDataType::Float, (double)middletone_w));
    }
    else if (PARAMETER_STRCMP(__name, "middletone_w") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)middletone_w));
    }

    // temporal_w
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("temporal_w", ParameterParserDataType::Float, (double)temporal_w));
    }
    else if (PARAMETER_STRCMP(__name, "temporal_w") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)temporal_w));
    }

    // max_percentile
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("max_percentile", ParameterParserDataType::Float, (double)max_percentile));
    }
    else if (PARAMETER_STRCMP(__name, "max_percentile") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)max_percentile));
    }

    // min_percentile
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("min_percentile", ParameterParserDataType::Float, (double)min_percentile));
    }
    else if (PARAMETER_STRCMP(__name, "min_percentile") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)min_percentile));
    }

    // reserved_1
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("reserved_1", ParameterParserDataType::Float, (double)reserved_1));
    }
    else if (PARAMETER_STRCMP(__name, "reserved_1") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)reserved_1));
    }

    // reserved_2
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("reserved_2", ParameterParserDataType::Float, (double)reserved_2));
    }
    else if (PARAMETER_STRCMP(__name, "reserved_2") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)reserved_2));
    }

    // extra_ratio_factor
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("extra_ratio_factor", ParameterParserDataType::Float, (double)extra_ratio_factor));
    }
    else if (PARAMETER_STRCMP(__name, "extra_ratio_factor") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)extra_ratio_factor));
    }

    // dark_index_range
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("dark_index_range", ParameterParserDataType::UInt32, (double)dark_index_range, 0));
    }
    else if (PARAMETER_STRCMP(__name, "dark_index_range") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)dark_index_range, 0));
    }

    // yratio_base_manual_tab
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("yratio_base_manual_tab", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "yratio_base_manual_tab") == 0)
    {
        __result = yratio_base_manual_tab.GetInfo(&__path[__pos], __info);
    }

    // manual_curve_strength
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("manual_curve_strength", ParameterParserDataType::Float, (double)manual_curve_strength));
    }
    else if (PARAMETER_STRCMP(__name, "manual_curve_strength") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)manual_curve_strength));
    }

    // midlight_threshold_low
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("midlight_threshold_low", ParameterParserDataType::UInt32, (double)midlight_threshold_low, 0));
    }
    else if (PARAMETER_STRCMP(__name, "midlight_threshold_low") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)midlight_threshold_low, 0));
    }

    // midlight_threshold_high
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("midlight_threshold_high", ParameterParserDataType::UInt32, (double)midlight_threshold_high, 0));
    }
    else if (PARAMETER_STRCMP(__name, "midlight_threshold_high") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)midlight_threshold_high, 0));
    }

    // lowlight_w
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("lowlight_w", ParameterParserDataType::Float, (double)lowlight_w));
    }
    else if (PARAMETER_STRCMP(__name, "lowlight_w") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)lowlight_w));
    }

    // highlight_w
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("highlight_w", ParameterParserDataType::Float, (double)highlight_w));
    }
    else if (PARAMETER_STRCMP(__name, "highlight_w") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)highlight_w));
    }

    // max_ratio
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("max_ratio", ParameterParserDataType::Float, (double)max_ratio));
    }
    else if (PARAMETER_STRCMP(__name, "max_ratio") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)max_ratio));
    }

    // luma_peak_th0
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_peak_th0", ParameterParserDataType::UInt32, (double)luma_peak_th0, 0));
    }
    else if (PARAMETER_STRCMP(__name, "luma_peak_th0") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)luma_peak_th0, 0));
    }

    // luma_peak_th1
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("luma_peak_th1", ParameterParserDataType::UInt32, (double)luma_peak_th1, 0));
    }
    else if (PARAMETER_STRCMP(__name, "luma_peak_th1") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::UInt32, (double)luma_peak_th1, 0));
    }

    // stretch_gain_0
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("stretch_gain_0", ParameterParserDataType::Float, (double)stretch_gain_0));
    }
    else if (PARAMETER_STRCMP(__name, "stretch_gain_0") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)stretch_gain_0));
    }

    // stretch_gain_1
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("stretch_gain_1", ParameterParserDataType::Float, (double)stretch_gain_1));
    }
    else if (PARAMETER_STRCMP(__name, "stretch_gain_1") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Float, (double)stretch_gain_1));
    }

    return __result;
}

bool gtm10_rgn_dataType::yratio_base_manual_tabStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "yratio_base_manual") == 0)
    {
        if (__index < 65)
        {
            ParameterUtils::DoubleToString((double)yratio_base_manual[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 65; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)yratio_base_manual[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool gtm10_rgn_dataType::yratio_base_manual_tabStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "yratio_base_manual") == 0)
    {
        if (__index < 65)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                yratio_base_manual[__index] = (float)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 65)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    yratio_base_manual[__index] = (float)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool gtm10_rgn_dataType::yratio_base_manual_tabStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // yratio_base_manual
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("yratio_base_manual", ParameterParserDataType::UInt32, true, false, 65));
    }

    return __result;
}

bool mod_gtm10_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "gtm10_rgn_data") == 0)
    {
        __result = gtm10_rgn_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_gtm10_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "gtm10_rgn_data") == 0)
    {
        __result = gtm10_rgn_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_gtm10_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "aec_trigger") == 0)
    {
        __result = aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // gtm10_rgn_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gtm10_rgn_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "gtm10_rgn_data") == 0)
    {
        __result = gtm10_rgn_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_gtm10_hdr_aec_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_gtm10_hdr_aec_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_gtm10_hdr_aec_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // hdr_aec_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_trigger") == 0)
    {
        __result = hdr_aec_trigger.GetInfo(&__path[__pos], __info);
    }

    // hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("hdr_aec_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "hdr_aec_data") == 0)
    {
        __result = hdr_aec_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_gtm10_hdr_aec_dataType::hdr_aec_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_gtm10_aec_data") == 0)
    {
        if (__index < mod_gtm10_aec_dataCount)
        {
            __result = mod_gtm10_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_gtm10_hdr_aec_dataType::hdr_aec_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_gtm10_aec_data") == 0)
    {
        if (__index < mod_gtm10_aec_dataCount)
        {
            __result = mod_gtm10_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_gtm10_hdr_aec_dataType::hdr_aec_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_gtm10_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_gtm10_aec_data", ParameterParserDataType::Structure, true, false, mod_gtm10_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_gtm10_aec_data") == 0)
    {
        if (__index < mod_gtm10_aec_dataCount)
        {
            __result = mod_gtm10_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_gtm10_aec_dataCount));
        }
    }

    return __result;
}

bool mod_gtm10_drc_gain_dataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool mod_gtm10_drc_gain_dataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool mod_gtm10_drc_gain_dataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // drc_gain_trigger
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_trigger", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_trigger") == 0)
    {
        __result = drc_gain_trigger.GetInfo(&__path[__pos], __info);
    }

    // drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("drc_gain_data", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "drc_gain_data") == 0)
    {
        __result = drc_gain_data.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool mod_gtm10_drc_gain_dataType::drc_gain_dataStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_gtm10_hdr_aec_data") == 0)
    {
        if (__index < mod_gtm10_hdr_aec_dataCount)
        {
            __result = mod_gtm10_hdr_aec_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool mod_gtm10_drc_gain_dataType::drc_gain_dataStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_gtm10_hdr_aec_data") == 0)
    {
        if (__index < mod_gtm10_hdr_aec_dataCount)
        {
            __result = mod_gtm10_hdr_aec_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool mod_gtm10_drc_gain_dataType::drc_gain_dataStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_gtm10_hdr_aec_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_gtm10_hdr_aec_data", ParameterParserDataType::Structure, true, false, mod_gtm10_hdr_aec_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_gtm10_hdr_aec_data") == 0)
    {
        if (__index < mod_gtm10_hdr_aec_dataCount)
        {
            __result = mod_gtm10_hdr_aec_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_gtm10_hdr_aec_dataCount));
        }
    }

    return __result;
}

bool chromatix_gtm10_coreType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_gtm10_drc_gain_data") == 0)
    {
        if (__index < mod_gtm10_drc_gain_dataCount)
        {
            __result = mod_gtm10_drc_gain_data[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool chromatix_gtm10_coreType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "mod_gtm10_drc_gain_data") == 0)
    {
        if (__index < mod_gtm10_drc_gain_dataCount)
        {
            __result = mod_gtm10_drc_gain_data[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool chromatix_gtm10_coreType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // mod_gtm10_drc_gain_data
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("mod_gtm10_drc_gain_data", ParameterParserDataType::Structure, true, false, mod_gtm10_drc_gain_dataCount));
    }
    else if (PARAMETER_STRCMP(__name, "mod_gtm10_drc_gain_data") == 0)
    {
        if (__index < mod_gtm10_drc_gain_dataCount)
        {
            __result = mod_gtm10_drc_gain_data[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, mod_gtm10_drc_gain_dataCount));
        }
    }

    return __result;
}

bool chromatix_gtm10_reserveType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "v2_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)v2_enable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "manual_curve_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)manual_curve_enable, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_gtm10_reserveType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "v2_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            v2_enable = (globalelements::enable_flag_type)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "manual_curve_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            manual_curve_enable = (globalelements::enable_flag_type)dblValue; 
        }
    }

    return __result;
}

bool chromatix_gtm10_reserveType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // v2_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("v2_enable", ParameterParserDataType::Int32, (double)v2_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "v2_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)v2_enable, 0));
    }

    // manual_curve_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("manual_curve_enable", ParameterParserDataType::Int32, (double)manual_curve_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "manual_curve_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)manual_curve_enable, 0));
    }

    return __result;
}

bool chromatix_gtm10Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_gtm10_reserve") == 0)
    {
        __result = chromatix_gtm10_reserve.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_gtm10_core") == 0)
    {
        __result = chromatix_gtm10_core.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool chromatix_gtm10Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_gtm10_reserve") == 0)
    {
        __result = chromatix_gtm10_reserve.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_gtm10_core") == 0)
    {
        __result = chromatix_gtm10_core.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool chromatix_gtm10Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable_section
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable_section", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "enable_section") == 0)
    {
        __result = enable_section.GetInfo(&__path[__pos], __info);
    }

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // parameter_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("parameter_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "parameter_version") == 0)
    {
        __result = parameter_version.GetInfo(&__path[__pos], __info);
    }

    // control_variables
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_variables", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_variables") == 0)
    {
        __result = control_variables.GetInfo(&__path[__pos], __info);
    }

    // control_method
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_method", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "control_method") == 0)
    {
        __result = control_method.GetInfo(&__path[__pos], __info);
    }

    // chromatix_gtm10_reserve
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_gtm10_reserve", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_gtm10_reserve") == 0)
    {
        __result = chromatix_gtm10_reserve.GetInfo(&__path[__pos], __info);
    }

    // chromatix_gtm10_core
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("chromatix_gtm10_core", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "chromatix_gtm10_core") == 0)
    {
        __result = chromatix_gtm10_core.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool chromatix_gtm10Type::enable_sectionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gtm_enable") == 0)
    {
        ParameterUtils::DoubleToString((double)gtm_enable, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_gtm10Type::enable_sectionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "gtm_enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            gtm_enable = (globalelements::enable_flag_type)dblValue; 
        }
    }

    return __result;
}

bool chromatix_gtm10Type::enable_sectionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // gtm_enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("gtm_enable", ParameterParserDataType::Int32, (double)gtm_enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "gtm_enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)gtm_enable, 0));
    }

    return __result;
}

bool chromatix_gtm10Type::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_gtm10Type::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_gtm10Type::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

bool chromatix_gtm10Type::parameter_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        PARAMETER_STRCPY(__value, __size, revision);
        __result = true;
    }

    return __result;
}

bool chromatix_gtm10Type::parameter_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const /*__value*/)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }

    return __result;
}

bool chromatix_gtm10Type::parameter_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("revision", ParameterParserDataType::String, revision));
    }
    else if (PARAMETER_STRCMP(__name, "revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, revision));
    }

    return __result;
}

bool chromatix_gtm10Type::control_variablesStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 3)
        {
            ParameterUtils::DoubleToString((double)(UINT32)control_var_type[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 3; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)(UINT32)control_var_type[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_gtm10Type::control_variablesStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "control_var_type") == 0)
    {
        if (__index < 3)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 3)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    control_var_type[__index] = (control_var_typeEnum)(UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool chromatix_gtm10Type::control_variablesStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // control_var_type
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("control_var_type", ParameterParserDataType::Enum, true, false, 3));
    }

    return __result;
}

bool chromatix_gtm10Type::control_methodStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_exp_control, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)aec_hdr_control, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool chromatix_gtm10Type::control_methodStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_exp_control = (ispglobalelements::tuning_control_aec_type)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            aec_hdr_control = (ispglobalelements::tuning_control_aec_hdr_type)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool chromatix_gtm10Type::control_methodStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // aec_exp_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_exp_control", ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_exp_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_exp_control, 0));
    }

    // aec_hdr_control
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("aec_hdr_control", ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }
    else if (PARAMETER_STRCMP(__name, "aec_hdr_control") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)aec_hdr_control, 0));
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_gtm10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(
    ParameterFileSymbolTableEntry* const entry,
    chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum::control_lux_idx):
            enumValue = chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum::control_lux_idx;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum::control_gain):
            enumValue = chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum::control_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum::control_drc_gain):
            enumValue = chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum::control_drc_gain;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio):
            enumValue = chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum::control_exp_time_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio):
            enumValue = chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum::control_aec_exp_sensitivity_ratio;
            result    = true;
            break;
        case static_cast<UINT32>(chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio):
            enumValue = chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum::control_exp_gain_ratio;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to chromatix_gtm10Type::control_variablesStruct::control_var_typeEnum", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_gtm10TypeClass::chromatix_gtm10TypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_gtm10_reserve);
    PARAMETER_INITIALIZE(chromatix_gtm10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_gtm10TypeClass::chromatix_gtm10TypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_gtm10_reserve);
    PARAMETER_INITIALIZE(chromatix_gtm10_core);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
chromatix_gtm10TypeClass::~chromatix_gtm10TypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* chromatix_gtm10TypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "gtm10_bps")) == 0)
    {
        name = "gtm10_bps";
    }
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "gtm10_ife")) == 0)
    {
        name = "gtm10_ife";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load gtm10_rgn_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool gtm10_rgn_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(maxval_th);
    PARAMETER_INITIALIZE(key_min_th);
    PARAMETER_INITIALIZE(key_max_th);
    PARAMETER_INITIALIZE(key_hist_bin_weight);
    PARAMETER_INITIALIZE(yout_maxval);
    PARAMETER_INITIALIZE(minval_th);
    PARAMETER_INITIALIZE(a_middletone);
    PARAMETER_INITIALIZE(middletone_w);
    PARAMETER_INITIALIZE(temporal_w);
    PARAMETER_INITIALIZE(max_percentile);
    PARAMETER_INITIALIZE(min_percentile);
    PARAMETER_INITIALIZE(reserved_1);
    PARAMETER_INITIALIZE(reserved_2);
    PARAMETER_INITIALIZE(extra_ratio_factor);
    PARAMETER_INITIALIZE(dark_index_range);
    PARAMETER_INITIALIZE(yratio_base_manual_tab);
    PARAMETER_INITIALIZE(manual_curve_strength);
    PARAMETER_INITIALIZE(midlight_threshold_low);
    PARAMETER_INITIALIZE(midlight_threshold_high);
    PARAMETER_INITIALIZE(lowlight_w);
    PARAMETER_INITIALIZE(highlight_w);
    PARAMETER_INITIALIZE(max_ratio);
    PARAMETER_INITIALIZE(luma_peak_th0);
    PARAMETER_INITIALIZE(luma_peak_th1);
    PARAMETER_INITIALIZE(stretch_gain_0);
    PARAMETER_INITIALIZE(stretch_gain_1);

    SYMBOL_TABLE_ENTRY_READ(entry, result, maxval_th, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, key_min_th, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, key_max_th, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, key_hist_bin_weight, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, yout_maxval, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minval_th, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, a_middletone, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, middletone_w, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, temporal_w, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, max_percentile, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, min_percentile, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, reserved_1, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, reserved_2, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, extra_ratio_factor, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, dark_index_range, alignment)
    if (result)
    {
        result = yratio_base_manual_tab.Load(entry, alignment);
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, manual_curve_strength, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, midlight_threshold_low, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, midlight_threshold_high, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, lowlight_w, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, highlight_w, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, max_ratio, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, luma_peak_th0, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, luma_peak_th1, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, stretch_gain_0, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, stretch_gain_1, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load gtm10_rgn_dataType_yratio_base_manual_tabStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool gtm10_rgn_dataType::yratio_base_manual_tabStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(yratio_base_manual);

    result = entry->ReadArray(yratio_base_manual, 65, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_gtm10_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_gtm10_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_trigger);
    PARAMETER_INITIALIZE(gtm10_rgn_data);

    result = aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = gtm10_rgn_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_gtm10_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_gtm10_hdr_aec_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(hdr_aec_trigger);
    PARAMETER_INITIALIZE(hdr_aec_data);

    result = hdr_aec_trigger.Load(entry, alignment);
    if (result)
    {
        result = hdr_aec_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_gtm10_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_gtm10_hdr_aec_dataType::hdr_aec_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_gtm10_aec_data);


    // Reading Array mod_gtm10_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_gtm10_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_gtm10_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_gtm10_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_gtm10_aec_dataDupInfo = pointerEntry->GetDupObject(mod_gtm10_aec_dataCount, file, line);
            if (mod_gtm10_aec_dataDupInfo != nullptr && mod_gtm10_aec_dataDupInfo->Object != nullptr)
            {
                mod_gtm10_aec_data = (mod_gtm10_aec_dataType*)mod_gtm10_aec_dataDupInfo->Object;
                if (mod_gtm10_aec_data == nullptr)
                {
                    if (mod_gtm10_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_gtm10_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_gtm10_aec_dataDupInfo->File, mod_gtm10_aec_dataDupInfo->Line, mod_gtm10_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_gtm10_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_gtm10_aec_dataDupInfo->Line, mod_gtm10_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_gtm10_aec_data == nullptr)
            {
                if (result && mod_gtm10_aec_dataCount > 0)
                {
                    mod_gtm10_aec_data = PARAMETER_NEW mod_gtm10_aec_dataType[mod_gtm10_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_gtm10_aec_data, mod_gtm10_aec_dataCount, file, line);
                }
                if (!result || mod_gtm10_aec_data == nullptr)
                {
                    if (mod_gtm10_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_gtm10_aec_data\n");
                    }
                    mod_gtm10_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_gtm10_aec_dataCount; i++)
                {
                    result = mod_gtm10_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_gtm10_aec_data == nullptr)
        {
            mod_gtm10_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_gtm10_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_gtm10_drc_gain_dataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(drc_gain_trigger);
    PARAMETER_INITIALIZE(drc_gain_data);

    result = drc_gain_trigger.Load(entry, alignment);
    if (result)
    {
        result = drc_gain_data.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load mod_gtm10_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool mod_gtm10_drc_gain_dataType::drc_gain_dataStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_gtm10_hdr_aec_data);


    // Reading Array mod_gtm10_hdr_aec_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_gtm10_hdr_aec_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_gtm10_hdr_aec_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_gtm10_hdr_aec_dataID = pointerEntry->ID;
            DupObjInfo* mod_gtm10_hdr_aec_dataDupInfo = pointerEntry->GetDupObject(mod_gtm10_hdr_aec_dataCount, file, line);
            if (mod_gtm10_hdr_aec_dataDupInfo != nullptr && mod_gtm10_hdr_aec_dataDupInfo->Object != nullptr)
            {
                mod_gtm10_hdr_aec_data = (mod_gtm10_hdr_aec_dataType*)mod_gtm10_hdr_aec_dataDupInfo->Object;
                if (mod_gtm10_hdr_aec_data == nullptr)
                {
                    if (mod_gtm10_hdr_aec_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_gtm10_hdr_aec_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_gtm10_hdr_aec_dataDupInfo->File, mod_gtm10_hdr_aec_dataDupInfo->Line, mod_gtm10_hdr_aec_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_gtm10_hdr_aec_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_gtm10_hdr_aec_dataDupInfo->Line, mod_gtm10_hdr_aec_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_gtm10_hdr_aec_data == nullptr)
            {
                if (result && mod_gtm10_hdr_aec_dataCount > 0)
                {
                    mod_gtm10_hdr_aec_data = PARAMETER_NEW mod_gtm10_hdr_aec_dataType[mod_gtm10_hdr_aec_dataCount];
                    (void)pointerEntry->SetDupObject(mod_gtm10_hdr_aec_data, mod_gtm10_hdr_aec_dataCount, file, line);
                }
                if (!result || mod_gtm10_hdr_aec_data == nullptr)
                {
                    if (mod_gtm10_hdr_aec_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_gtm10_hdr_aec_data\n");
                    }
                    mod_gtm10_hdr_aec_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_gtm10_hdr_aec_dataCount; i++)
                {
                    result = mod_gtm10_hdr_aec_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_gtm10_hdr_aec_data == nullptr)
        {
            mod_gtm10_hdr_aec_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_gtm10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_gtm10_coreType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(mod_gtm10_drc_gain_data);


    // Reading Array mod_gtm10_drc_gain_data from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        mod_gtm10_drc_gain_dataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, mod_gtm10_drc_gain_dataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            mod_gtm10_drc_gain_dataID = pointerEntry->ID;
            DupObjInfo* mod_gtm10_drc_gain_dataDupInfo = pointerEntry->GetDupObject(mod_gtm10_drc_gain_dataCount, file, line);
            if (mod_gtm10_drc_gain_dataDupInfo != nullptr && mod_gtm10_drc_gain_dataDupInfo->Object != nullptr)
            {
                mod_gtm10_drc_gain_data = (mod_gtm10_drc_gain_dataType*)mod_gtm10_drc_gain_dataDupInfo->Object;
                if (mod_gtm10_drc_gain_data == nullptr)
                {
                    if (mod_gtm10_drc_gain_dataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_gtm10_drc_gain_data duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            mod_gtm10_drc_gain_dataDupInfo->File, mod_gtm10_drc_gain_dataDupInfo->Line, mod_gtm10_drc_gain_dataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "mod_gtm10_drc_gain_data duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            mod_gtm10_drc_gain_dataDupInfo->Line, mod_gtm10_drc_gain_dataDupInfo->RefCount);
                    }
                }
            }

            if (mod_gtm10_drc_gain_data == nullptr)
            {
                if (result && mod_gtm10_drc_gain_dataCount > 0)
                {
                    mod_gtm10_drc_gain_data = PARAMETER_NEW mod_gtm10_drc_gain_dataType[mod_gtm10_drc_gain_dataCount];
                    (void)pointerEntry->SetDupObject(mod_gtm10_drc_gain_data, mod_gtm10_drc_gain_dataCount, file, line);
                }
                if (!result || mod_gtm10_drc_gain_data == nullptr)
                {
                    if (mod_gtm10_drc_gain_dataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate mod_gtm10_drc_gain_data\n");
                    }
                    mod_gtm10_drc_gain_dataCount = 0;
                }
                for (UINT32 i = 0; result && i < mod_gtm10_drc_gain_dataCount; i++)
                {
                    result = mod_gtm10_drc_gain_data[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (mod_gtm10_drc_gain_data == nullptr)
        {
            mod_gtm10_drc_gain_dataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_gtm10_reserveType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_gtm10_reserveType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(v2_enable);
    PARAMETER_INITIALIZE(manual_curve_enable);

    SYMBOL_TABLE_ENTRY_READ(entry, result, v2_enable, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, manual_curve_enable, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load chromatix_gtm10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_gtm10Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable_section);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(parameter_version);
    PARAMETER_INITIALIZE(control_variables);
    PARAMETER_INITIALIZE(control_method);
    PARAMETER_INITIALIZE(chromatix_gtm10_reserve);
    PARAMETER_INITIALIZE(chromatix_gtm10_core);

    result = enable_section.Load(entry, alignment);
    if (result)
    {
        result = module_version.Load(entry, alignment);
    }
    if (result)
    {
        result = parameter_version.Load(entry, alignment);
    }
    if (result)
    {
        result = control_variables.Load(entry, alignment);
    }
    if (result)
    {
        result = control_method.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_gtm10_reserve.Load(entry, alignment);
    }
    if (result)
    {
        result = chromatix_gtm10_core.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load enable_sectionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_gtm10Type::enable_sectionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(gtm_enable);

    SYMBOL_TABLE_ENTRY_READ(entry, result, gtm_enable, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_gtm10Type::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_gtm10Type::parameter_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(revision);


    // Reading String revision from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, revision, count, alignment)
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_variablesStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_gtm10Type::control_variablesStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(control_var_type);

    for (UINT32 i = 0; result && i < 3; i++)
    {
        result = chromatix_gtm10Type::control_variablesStruct::ReadEnum_control_var_typeEnum(entry, control_var_type[i], alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load control_methodStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_gtm10Type::control_methodStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(aec_exp_control);
    PARAMETER_INITIALIZE(aec_hdr_control);

    result = ispglobalelements::ReadEnum_tuning_control_aec_type(entry, aec_exp_control, alignment);
    if (result)
    {
        result = ispglobalelements::ReadEnum_tuning_control_aec_hdr_type(entry, aec_hdr_control, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_gtm10_hdr_aec_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_gtm10_hdr_aec_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    hdr_aec_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_gtm10_hdr_aec_dataType_hdr_aec_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_gtm10_hdr_aec_dataType::hdr_aec_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(mod_gtm10_aec_data))
    {
        PARAMETER_DELETE[] mod_gtm10_aec_data;
    }
    mod_gtm10_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_gtm10_drc_gain_dataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_gtm10_drc_gain_dataType::Unload(ParameterFileSymbolTable* const __table)
{
    drc_gain_data.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload mod_gtm10_drc_gain_dataType_drc_gain_dataStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void mod_gtm10_drc_gain_dataType::drc_gain_dataStruct::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_gtm10_hdr_aec_dataCount; i++)
    {
        mod_gtm10_hdr_aec_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_gtm10_hdr_aec_data))
    {
        PARAMETER_DELETE[] mod_gtm10_hdr_aec_data;
    }
    mod_gtm10_hdr_aec_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_gtm10_coreType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_gtm10_coreType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < mod_gtm10_drc_gain_dataCount; i++)
    {
        mod_gtm10_drc_gain_data[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(mod_gtm10_drc_gain_data))
    {
        PARAMETER_DELETE[] mod_gtm10_drc_gain_data;
    }
    mod_gtm10_drc_gain_data = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload chromatix_gtm10Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_gtm10Type::Unload(ParameterFileSymbolTable* const __table)
{
    parameter_version.Unload(__table);
    chromatix_gtm10_core.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload parameter_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_gtm10Type::parameter_versionStruct::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(revision))
    {
        PARAMETER_DELETE[] revision;
    }
    revision = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_gtm10Type::Release()
{
    ((chromatix_gtm10TypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 chromatix_gtm10Type::GetModified()
{
    return ((chromatix_gtm10TypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* chromatix_gtm10TypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    chromatix_gtm10TypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (chromatix_gtm10TypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW chromatix_gtm10TypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_gtm10TypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create chromatix_gtm10TypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool chromatix_gtm10TypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        chromatix_gtm10TypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "chromatix_gtm10TypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_gtm10TypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void chromatix_gtm10TypeClass::Release()
{
    ParameterModule::Release();
}

GTM_1_0_0_NAMESPACE_END
